# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class LearnedInformation(Base):
	"""The LearnedInformation class encapsulates a required learnedInformation node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the LearnedInformation property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'learnedInformation'

	def __init__(self, parent):
		super(LearnedInformation, self).__init__(parent)

	@property
	def DmLearnedInfo(self):
		"""An instance of the DmLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplstp.router.learnedinformation.dmlearnedinfo.dmlearnedinfo.DmLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplstp.router.learnedinformation.dmlearnedinfo.dmlearnedinfo import DmLearnedInfo
		return DmLearnedInfo(self)

	@property
	def GeneralLearnedInfo(self):
		"""An instance of the GeneralLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplstp.router.learnedinformation.generallearnedinfo.generallearnedinfo.GeneralLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplstp.router.learnedinformation.generallearnedinfo.generallearnedinfo import GeneralLearnedInfo
		return GeneralLearnedInfo(self)

	@property
	def LmLearnedInfo(self):
		"""An instance of the LmLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplstp.router.learnedinformation.lmlearnedinfo.lmlearnedinfo.LmLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplstp.router.learnedinformation.lmlearnedinfo.lmlearnedinfo import LmLearnedInfo
		return LmLearnedInfo(self)

	@property
	def PingLearnedInfo(self):
		"""An instance of the PingLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplstp.router.learnedinformation.pinglearnedinfo.pinglearnedinfo.PingLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplstp.router.learnedinformation.pinglearnedinfo.pinglearnedinfo import PingLearnedInfo
		return PingLearnedInfo(self)

	@property
	def TraceRouteLearnedInfo(self):
		"""An instance of the TraceRouteLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplstp.router.learnedinformation.traceroutelearnedinfo.traceroutelearnedinfo.TraceRouteLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplstp.router.learnedinformation.traceroutelearnedinfo.traceroutelearnedinfo import TraceRouteLearnedInfo
		return TraceRouteLearnedInfo(self)

	@property
	def AlarmTrigger(self):
		"""This signifies the alarm trigger. Possible values include Clear and Start.

		Returns:
			str(clear|start)
		"""
		return self._get_attribute('alarmTrigger')
	@AlarmTrigger.setter
	def AlarmTrigger(self, value):
		self._set_attribute('alarmTrigger', value)

	@property
	def AlarmType(self):
		"""This signifies the alarm type. Possible values include IETF and Y.1731.

		Returns:
			str(ietf|y1731)
		"""
		return self._get_attribute('alarmType')
	@AlarmType.setter
	def AlarmType(self, value):
		self._set_attribute('alarmType', value)

	@property
	def ApsTriggerType(self):
		"""This signifies the Trigger type. Possible values include Clear, Exercise, Forced Switch, Freeze, Lockout, Manual Switch To Protect and Manual Switch To Working.

		Returns:
			str(clear|forcedSwitch|manualSwitchToProtect|manualSwitchToWorking|lockout|exercise|freeze)
		"""
		return self._get_attribute('apsTriggerType')
	@ApsTriggerType.setter
	def ApsTriggerType(self, value):
		self._set_attribute('apsTriggerType', value)

	@property
	def CccvPauseTriggerOption(self):
		"""This signifies the cccv pause trigger option. Possible values include TX, RX and TXRX.

		Returns:
			str(tx|rx|txRx)
		"""
		return self._get_attribute('cccvPauseTriggerOption')
	@CccvPauseTriggerOption.setter
	def CccvPauseTriggerOption(self, value):
		self._set_attribute('cccvPauseTriggerOption', value)

	@property
	def CccvResumeTriggerOption(self):
		"""This signifies the cccv resume trigger option. Possible values include Tx, Rx and TxRx.

		Returns:
			str(tx|rx|txRx)
		"""
		return self._get_attribute('cccvResumeTriggerOption')
	@CccvResumeTriggerOption.setter
	def CccvResumeTriggerOption(self, value):
		self._set_attribute('cccvResumeTriggerOption', value)

	@property
	def ChangeSessionParameters(self):
		"""This specifies the minimum receive interval of cc messages in millisecond, at the source side that the user intends to set on the fly.

		Returns:
			bool
		"""
		return self._get_attribute('changeSessionParameters')
	@ChangeSessionParameters.setter
	def ChangeSessionParameters(self, value):
		self._set_attribute('changeSessionParameters', value)

	@property
	def ClearMisconnectivityDefect(self):
		"""If set true all the misconnectivity defects that have been triggered earlier with any type gets cleared.

		Returns:
			bool
		"""
		return self._get_attribute('clearMisconnectivityDefect')
	@ClearMisconnectivityDefect.setter
	def ClearMisconnectivityDefect(self, value):
		self._set_attribute('clearMisconnectivityDefect', value)

	@property
	def CounterType(self):
		"""This signifies the LM Counter Type. Possible values include 32 Bit (default) and 64 Bit.

		Returns:
			str(32Bit|64Bit)
		"""
		return self._get_attribute('counterType')
	@CounterType.setter
	def CounterType(self, value):
		self._set_attribute('counterType', value)

	@property
	def DmInterval(self):
		"""This signifies the DM interval in milliseconds.

		Returns:
			number
		"""
		return self._get_attribute('dmInterval')
	@DmInterval.setter
	def DmInterval(self, value):
		self._set_attribute('dmInterval', value)

	@property
	def DmIterations(self):
		"""This signifies the total number of DM queries to be sent.

		Returns:
			number
		"""
		return self._get_attribute('dmIterations')
	@DmIterations.setter
	def DmIterations(self, value):
		self._set_attribute('dmIterations', value)

	@property
	def DmMode(self):
		"""This signifies the DM mode. The possible values include Response Expected and No Response Expected.

		Returns:
			str(noResponseExpected|responseExpected)
		"""
		return self._get_attribute('dmMode')
	@DmMode.setter
	def DmMode(self, value):
		self._set_attribute('dmMode', value)

	@property
	def DmPadLen(self):
		"""This signifies the DM pad length.

		Returns:
			number
		"""
		return self._get_attribute('dmPadLen')
	@DmPadLen.setter
	def DmPadLen(self, value):
		self._set_attribute('dmPadLen', value)

	@property
	def DmRequestPaddedReply(self):
		"""This signifies the DM request as a padded reply.

		Returns:
			bool
		"""
		return self._get_attribute('dmRequestPaddedReply')
	@DmRequestPaddedReply.setter
	def DmRequestPaddedReply(self, value):
		self._set_attribute('dmRequestPaddedReply', value)

	@property
	def DmTimeFormat(self):
		"""This signifies the DM time format. The possible values include IEEE and NTP.

		Returns:
			str(ieee|ntp)
		"""
		return self._get_attribute('dmTimeFormat')
	@DmTimeFormat.setter
	def DmTimeFormat(self, value):
		self._set_attribute('dmTimeFormat', value)

	@property
	def DmTrafficClass(self):
		"""This signifies the DM traffic class value.

		Returns:
			number
		"""
		return self._get_attribute('dmTrafficClass')
	@DmTrafficClass.setter
	def DmTrafficClass(self, value):
		self._set_attribute('dmTrafficClass', value)

	@property
	def DmType(self):
		"""This signifies the DM Type. Possible values include IETF and Y.1731.

		Returns:
			str(ietf|y1731)
		"""
		return self._get_attribute('dmType')
	@DmType.setter
	def DmType(self, value):
		self._set_attribute('dmType', value)

	@property
	def EnableAlarm(self):
		"""This signifies the enablement of the Alarm and the fields under it.

		Returns:
			bool
		"""
		return self._get_attribute('enableAlarm')
	@EnableAlarm.setter
	def EnableAlarm(self, value):
		self._set_attribute('enableAlarm', value)

	@property
	def EnableAlarmAis(self):
		"""DEPRECATED This signifies the enablement of the Alarm AIS.

		Returns:
			bool
		"""
		return self._get_attribute('enableAlarmAis')
	@EnableAlarmAis.setter
	def EnableAlarmAis(self, value):
		self._set_attribute('enableAlarmAis', value)

	@property
	def EnableAlarmFastClear(self):
		"""DEPRECATED Clears the Alarm State in 10 seconds

		Returns:
			bool
		"""
		return self._get_attribute('enableAlarmFastClear')
	@EnableAlarmFastClear.setter
	def EnableAlarmFastClear(self, value):
		self._set_attribute('enableAlarmFastClear', value)

	@property
	def EnableAlarmLck(self):
		"""DEPRECATED This signifies the enablement of the Alarm lck.

		Returns:
			bool
		"""
		return self._get_attribute('enableAlarmLck')
	@EnableAlarmLck.setter
	def EnableAlarmLck(self, value):
		self._set_attribute('enableAlarmLck', value)

	@property
	def EnableAlarmSetLdi(self):
		"""DEPRECATED This signifies the enablement of the Alarm Set LDI.

		Returns:
			bool
		"""
		return self._get_attribute('enableAlarmSetLdi')
	@EnableAlarmSetLdi.setter
	def EnableAlarmSetLdi(self, value):
		self._set_attribute('enableAlarmSetLdi', value)

	@property
	def EnableApsTrigger(self):
		"""DEPRECATED This signifies the enablement of APS trigger.

		Returns:
			bool
		"""
		return self._get_attribute('enableApsTrigger')
	@EnableApsTrigger.setter
	def EnableApsTrigger(self, value):
		self._set_attribute('enableApsTrigger', value)

	@property
	def EnableCccvPause(self):
		"""DEPRECATED This signifies the enabling of CCCV Pause.

		Returns:
			bool
		"""
		return self._get_attribute('enableCccvPause')
	@EnableCccvPause.setter
	def EnableCccvPause(self, value):
		self._set_attribute('enableCccvPause', value)

	@property
	def EnableCccvResume(self):
		"""DEPRECATED This signifies the enablement of CCCV Resume.

		Returns:
			bool
		"""
		return self._get_attribute('enableCccvResume')
	@EnableCccvResume.setter
	def EnableCccvResume(self, value):
		self._set_attribute('enableCccvResume', value)

	@property
	def EnableDmTrigger(self):
		"""DEPRECATED This signifies the enablement of the DM trigger.

		Returns:
			bool
		"""
		return self._get_attribute('enableDmTrigger')
	@EnableDmTrigger.setter
	def EnableDmTrigger(self, value):
		self._set_attribute('enableDmTrigger', value)

	@property
	def EnableLmTrigger(self):
		"""DEPRECATED This signifies the enablement of the LM trigger.

		Returns:
			bool
		"""
		return self._get_attribute('enableLmTrigger')
	@EnableLmTrigger.setter
	def EnableLmTrigger(self, value):
		self._set_attribute('enableLmTrigger', value)

	@property
	def EnableLspPing(self):
		"""DEPRECATED This signifies the enablement of the LSP Ping.

		Returns:
			bool
		"""
		return self._get_attribute('enableLspPing')
	@EnableLspPing.setter
	def EnableLspPing(self, value):
		self._set_attribute('enableLspPing', value)

	@property
	def EnableLspPingFecStackValidation(self):
		"""DEPRECATED This signifies the enablement of the FEC Stack Validation.

		Returns:
			bool
		"""
		return self._get_attribute('enableLspPingFecStackValidation')
	@EnableLspPingFecStackValidation.setter
	def EnableLspPingFecStackValidation(self, value):
		self._set_attribute('enableLspPingFecStackValidation', value)

	@property
	def EnableLspPingValidateReversePath(self):
		"""DEPRECATED If true validate reverse path bit is set in lsp ping message.

		Returns:
			bool
		"""
		return self._get_attribute('enableLspPingValidateReversePath')
	@EnableLspPingValidateReversePath.setter
	def EnableLspPingValidateReversePath(self, value):
		self._set_attribute('enableLspPingValidateReversePath', value)

	@property
	def EnableLspTraceRoute(self):
		"""DEPRECATED This signifies the enablement of the lsp traceroute.

		Returns:
			bool
		"""
		return self._get_attribute('enableLspTraceRoute')
	@EnableLspTraceRoute.setter
	def EnableLspTraceRoute(self, value):
		self._set_attribute('enableLspTraceRoute', value)

	@property
	def EnableLspTraceRouteFecStackValidation(self):
		"""DEPRECATED This signifies the enablement of the FEC Stack Validation.

		Returns:
			bool
		"""
		return self._get_attribute('enableLspTraceRouteFecStackValidation')
	@EnableLspTraceRouteFecStackValidation.setter
	def EnableLspTraceRouteFecStackValidation(self, value):
		self._set_attribute('enableLspTraceRouteFecStackValidation', value)

	@property
	def EnablePwStatusClear(self):
		"""DEPRECATED This signifies the enablement of the PW Status Clear and the fields under it.

		Returns:
			bool
		"""
		return self._get_attribute('enablePwStatusClear')
	@EnablePwStatusClear.setter
	def EnablePwStatusClear(self, value):
		self._set_attribute('enablePwStatusClear', value)

	@property
	def EnablePwStatusFault(self):
		"""DEPRECATED This signifies the enablement of the PW Status Fault.

		Returns:
			bool
		"""
		return self._get_attribute('enablePwStatusFault')
	@EnablePwStatusFault.setter
	def EnablePwStatusFault(self, value):
		self._set_attribute('enablePwStatusFault', value)

	@property
	def IsDmLearnedInformationRefreshed(self):
		"""DEPRECATED This signifies the refresheing of the DM learned information.

		Returns:
			bool
		"""
		return self._get_attribute('isDmLearnedInformationRefreshed')

	@property
	def IsGeneralLearnedInformationRefreshed(self):
		"""DEPRECATED This signifies the refereshing of the general learned information.

		Returns:
			bool
		"""
		return self._get_attribute('isGeneralLearnedInformationRefreshed')

	@property
	def IsLmLearnedInformationRefreshed(self):
		"""DEPRECATED This signifies the refresheing of the LM learned information.

		Returns:
			bool
		"""
		return self._get_attribute('isLmLearnedInformationRefreshed')

	@property
	def IsPingLearnedInformationRefreshed(self):
		"""DEPRECATED This signifies the refresheing of the Ping learned information.

		Returns:
			bool
		"""
		return self._get_attribute('isPingLearnedInformationRefreshed')

	@property
	def IsTraceRouteLearnedInformationRefreshed(self):
		"""DEPRECATED This signifies the refresheing of the Trace Route learned information.

		Returns:
			bool
		"""
		return self._get_attribute('isTraceRouteLearnedInformationRefreshed')

	@property
	def LastDmResponseTimeout(self):
		"""DEPRECATED This signifies the last DM Response Timeout.

		Returns:
			number
		"""
		return self._get_attribute('lastDmResponseTimeout')
	@LastDmResponseTimeout.setter
	def LastDmResponseTimeout(self, value):
		self._set_attribute('lastDmResponseTimeout', value)

	@property
	def LastLmResponseTimeout(self):
		"""DEPRECATED This signifies the last LM response timeout.

		Returns:
			number
		"""
		return self._get_attribute('lastLmResponseTimeout')
	@LastLmResponseTimeout.setter
	def LastLmResponseTimeout(self, value):
		self._set_attribute('lastLmResponseTimeout', value)

	@property
	def LmInitialRxValue(self):
		"""DEPRECATED This signifies the LM Initial Rx value.

		Returns:
			number
		"""
		return self._get_attribute('lmInitialRxValue')
	@LmInitialRxValue.setter
	def LmInitialRxValue(self, value):
		self._set_attribute('lmInitialRxValue', value)

	@property
	def LmInitialTxValue(self):
		"""DEPRECATED This signifies the LM Initial Tx value.

		Returns:
			number
		"""
		return self._get_attribute('lmInitialTxValue')
	@LmInitialTxValue.setter
	def LmInitialTxValue(self, value):
		self._set_attribute('lmInitialTxValue', value)

	@property
	def LmInterval(self):
		"""DEPRECATED This signifies the LM interval in milliseconds.

		Returns:
			number
		"""
		return self._get_attribute('lmInterval')
	@LmInterval.setter
	def LmInterval(self, value):
		self._set_attribute('lmInterval', value)

	@property
	def LmIterations(self):
		"""DEPRECATED This signifies the number of LM queries to be sent.

		Returns:
			number
		"""
		return self._get_attribute('lmIterations')
	@LmIterations.setter
	def LmIterations(self, value):
		self._set_attribute('lmIterations', value)

	@property
	def LmMode(self):
		"""DEPRECATED This signifies the LM mode. Possible values include Response Expected and No Response Expected.

		Returns:
			str(responseExpected|noResponseExpected)
		"""
		return self._get_attribute('lmMode')
	@LmMode.setter
	def LmMode(self, value):
		self._set_attribute('lmMode', value)

	@property
	def LmRxStep(self):
		"""DEPRECATED This signifies the LM Rx step value.

		Returns:
			number
		"""
		return self._get_attribute('lmRxStep')
	@LmRxStep.setter
	def LmRxStep(self, value):
		self._set_attribute('lmRxStep', value)

	@property
	def LmTrafficClass(self):
		"""DEPRECATED This signifies the LM Traffic Class.

		Returns:
			number
		"""
		return self._get_attribute('lmTrafficClass')
	@LmTrafficClass.setter
	def LmTrafficClass(self, value):
		self._set_attribute('lmTrafficClass', value)

	@property
	def LmTxStep(self):
		"""DEPRECATED This signifies the LM Tx Step value.

		Returns:
			number
		"""
		return self._get_attribute('lmTxStep')
	@LmTxStep.setter
	def LmTxStep(self, value):
		self._set_attribute('lmTxStep', value)

	@property
	def LmType(self):
		"""DEPRECATED This signifies the LM type. The possible values include IETF and Y.1731.

		Returns:
			str(ietf|y1731)
		"""
		return self._get_attribute('lmType')
	@LmType.setter
	def LmType(self, value):
		self._set_attribute('lmType', value)

	@property
	def LspPingEncapsulationType(self):
		"""DEPRECATED This signifies the encapsulation type with which the lsp ping request message will be sent out. The possible values include UDP-IP-GAch and GAch.

		Returns:
			str(GAch|UDP over IP over GAch)
		"""
		return self._get_attribute('lspPingEncapsulationType')
	@LspPingEncapsulationType.setter
	def LspPingEncapsulationType(self, value):
		self._set_attribute('lspPingEncapsulationType', value)

	@property
	def LspPingResponseTimeout(self):
		"""DEPRECATED This signifies the response timeout in milliseconds.

		Returns:
			number
		"""
		return self._get_attribute('lspPingResponseTimeout')
	@LspPingResponseTimeout.setter
	def LspPingResponseTimeout(self, value):
		self._set_attribute('lspPingResponseTimeout', value)

	@property
	def LspPingTtlValue(self):
		"""DEPRECATED This signifies the LSP Ping Ttl value.

		Returns:
			number
		"""
		return self._get_attribute('lspPingTtlValue')
	@LspPingTtlValue.setter
	def LspPingTtlValue(self, value):
		self._set_attribute('lspPingTtlValue', value)

	@property
	def LspTraceRouteEncapsulationType(self):
		"""DEPRECATED This signifies the encapsulation type with which the Trace route request message will be sen out. The possible values include UDP-IP-GAch and GAch.

		Returns:
			str(GAch|UDP over IP over GAch)
		"""
		return self._get_attribute('lspTraceRouteEncapsulationType')
	@LspTraceRouteEncapsulationType.setter
	def LspTraceRouteEncapsulationType(self, value):
		self._set_attribute('lspTraceRouteEncapsulationType', value)

	@property
	def LspTraceRouteResponseTimeout(self):
		"""DEPRECATED This signifies the response timeout in milliseconds.

		Returns:
			number
		"""
		return self._get_attribute('lspTraceRouteResponseTimeout')
	@LspTraceRouteResponseTimeout.setter
	def LspTraceRouteResponseTimeout(self, value):
		self._set_attribute('lspTraceRouteResponseTimeout', value)

	@property
	def LspTraceRouteTtlLimit(self):
		"""DEPRECATED This signifies the max TTL till which the Echo Request will be sent out as part of trace route process.

		Returns:
			number
		"""
		return self._get_attribute('lspTraceRouteTtlLimit')
	@LspTraceRouteTtlLimit.setter
	def LspTraceRouteTtlLimit(self, value):
		self._set_attribute('lspTraceRouteTtlLimit', value)

	@property
	def MinRxInterval(self):
		"""DEPRECATED This signifies the minimum receive interval of cc messages in millisecond, at the source side that the user intends to set on the fly.

		Returns:
			str(10|100|1000|10000|3.33|60000|600000)
		"""
		return self._get_attribute('minRxInterval')
	@MinRxInterval.setter
	def MinRxInterval(self, value):
		self._set_attribute('minRxInterval', value)

	@property
	def MinTxInterval(self):
		"""DEPRECATED This signifies the learned information minimum transmit interval, in milliseconds. This specifies the minimum transmit interval of cc messages in millisecond, at the source side that the user intends to set on the fly.

		Returns:
			str(10|100|1000|10000|3.33|60000|600000)
		"""
		return self._get_attribute('minTxInterval')
	@MinTxInterval.setter
	def MinTxInterval(self, value):
		self._set_attribute('minTxInterval', value)

	@property
	def MisconnectivityDefect(self):
		"""DEPRECATED To enable misconnectivity defect on the fly by changing LSP/PW MEP/MEG Id parameter or Your Discriminator on the source side.

		Returns:
			bool
		"""
		return self._get_attribute('misconnectivityDefect')
	@MisconnectivityDefect.setter
	def MisconnectivityDefect(self, value):
		self._set_attribute('misconnectivityDefect', value)

	@property
	def MisconnectivityDefectOption(self):
		"""DEPRECATED To enable misconnectivity defect on the fly by changing LSP/PW MEP/MEG Id parameter or Your Discriminator on the source side.

		Returns:
			str(unexpectedMepId|unexpectedYourDiscriminator)
		"""
		return self._get_attribute('misconnectivityDefectOption')
	@MisconnectivityDefectOption.setter
	def MisconnectivityDefectOption(self, value):
		self._set_attribute('misconnectivityDefectOption', value)

	@property
	def OnDemandCvDownstreamAddressType(self):
		"""DEPRECATED This signifies the Address Type of the Downstream or Detailed Downstream Mapping TLV. This can be of three types.

		Returns:
			str(ipv4Numbered|ipv4Unnumbered|nonIp)
		"""
		return self._get_attribute('onDemandCvDownstreamAddressType')
	@OnDemandCvDownstreamAddressType.setter
	def OnDemandCvDownstreamAddressType(self, value):
		self._set_attribute('onDemandCvDownstreamAddressType', value)

	@property
	def OnDemandCvDownstreamIpAddress(self):
		"""DEPRECATED This signifies the inclusion of the IP address in Downstream or Detailed Downstream Mapping TLV. This takes input in ip address format.

		Returns:
			str
		"""
		return self._get_attribute('onDemandCvDownstreamIpAddress')
	@OnDemandCvDownstreamIpAddress.setter
	def OnDemandCvDownstreamIpAddress(self, value):
		self._set_attribute('onDemandCvDownstreamIpAddress', value)

	@property
	def OnDemandCvDsIflag(self):
		"""DEPRECATED This signifies the setting of I bit in the DS Flag of Downstream or Detailed Downstream Mapping TLV.

		Returns:
			bool
		"""
		return self._get_attribute('onDemandCvDsIflag')
	@OnDemandCvDsIflag.setter
	def OnDemandCvDsIflag(self, value):
		self._set_attribute('onDemandCvDsIflag', value)

	@property
	def OnDemandCvDsNflag(self):
		"""DEPRECATED If set true, N bit is set in the DS Flag of Downstream or Detailed Downstream Mapping TLV.

		Returns:
			bool
		"""
		return self._get_attribute('onDemandCvDsNflag')
	@OnDemandCvDsNflag.setter
	def OnDemandCvDsNflag(self, value):
		self._set_attribute('onDemandCvDsNflag', value)

	@property
	def OnDemandCvEgressIfNumber(self):
		"""DEPRECATED This signifies the Egress If Number, if address type of Downstream or Detailed Downstream Mapping TLV is set to nonIP.

		Returns:
			number
		"""
		return self._get_attribute('onDemandCvEgressIfNumber')
	@OnDemandCvEgressIfNumber.setter
	def OnDemandCvEgressIfNumber(self, value):
		self._set_attribute('onDemandCvEgressIfNumber', value)

	@property
	def OnDemandCvIncludeDestinationIdentifierTlv(self):
		"""DEPRECATED If channel type is set to GAch, this signifies the inclusion of Destination Identifier TLV in the On Demand CV message. Possible values are true or false.

		Returns:
			bool
		"""
		return self._get_attribute('onDemandCvIncludeDestinationIdentifierTlv')
	@OnDemandCvIncludeDestinationIdentifierTlv.setter
	def OnDemandCvIncludeDestinationIdentifierTlv(self, value):
		self._set_attribute('onDemandCvIncludeDestinationIdentifierTlv', value)

	@property
	def OnDemandCvIncludeDetailedDownstreamMappingTlv(self):
		"""DEPRECATED This signifies the inclusion of the Detailed Downstream Mapping TLV in on demand cv message. Possible values are true or false.

		Returns:
			bool
		"""
		return self._get_attribute('onDemandCvIncludeDetailedDownstreamMappingTlv')
	@OnDemandCvIncludeDetailedDownstreamMappingTlv.setter
	def OnDemandCvIncludeDetailedDownstreamMappingTlv(self, value):
		self._set_attribute('onDemandCvIncludeDetailedDownstreamMappingTlv', value)

	@property
	def OnDemandCvIncludeDownstreamMappingTlv(self):
		"""DEPRECATED This signifies the inclusion of Downstream Mapping TLV in on demand cv messages.

		Returns:
			bool
		"""
		return self._get_attribute('onDemandCvIncludeDownstreamMappingTlv')
	@OnDemandCvIncludeDownstreamMappingTlv.setter
	def OnDemandCvIncludeDownstreamMappingTlv(self, value):
		self._set_attribute('onDemandCvIncludeDownstreamMappingTlv', value)

	@property
	def OnDemandCvIncludePadTlv(self):
		"""DEPRECATED This signifies the inclusion of Pad TLV in on demand cv messages (ping or traceroute).

		Returns:
			bool
		"""
		return self._get_attribute('onDemandCvIncludePadTlv')
	@OnDemandCvIncludePadTlv.setter
	def OnDemandCvIncludePadTlv(self, value):
		self._set_attribute('onDemandCvIncludePadTlv', value)

	@property
	def OnDemandCvIncludeReplyTosByteTlv(self):
		"""DEPRECATED This signifies the inclusion of Reply Tos Byte TLV in on demand cv messages, if channel type is configured ip-udp-gach.

		Returns:
			bool
		"""
		return self._get_attribute('onDemandCvIncludeReplyTosByteTlv')
	@OnDemandCvIncludeReplyTosByteTlv.setter
	def OnDemandCvIncludeReplyTosByteTlv(self, value):
		self._set_attribute('onDemandCvIncludeReplyTosByteTlv', value)

	@property
	def OnDemandCvIncludeSourceIdentifierTlv(self):
		"""DEPRECATED If channel type is set to GAch, this signifies the inclusion of Source Identifier TLV in the On Demand CV message. Possible values are true or false.

		Returns:
			bool
		"""
		return self._get_attribute('onDemandCvIncludeSourceIdentifierTlv')
	@OnDemandCvIncludeSourceIdentifierTlv.setter
	def OnDemandCvIncludeSourceIdentifierTlv(self, value):
		self._set_attribute('onDemandCvIncludeSourceIdentifierTlv', value)

	@property
	def OnDemandCvIngressIfNumber(self):
		"""DEPRECATED This signifies the Ingress If Number, if address type of Downstream or Detailed Downstream Mapping TLV is set to nonIP.

		Returns:
			number
		"""
		return self._get_attribute('onDemandCvIngressIfNumber')
	@OnDemandCvIngressIfNumber.setter
	def OnDemandCvIngressIfNumber(self, value):
		self._set_attribute('onDemandCvIngressIfNumber', value)

	@property
	def OnDemandCvNumberedDownstreamInterfaceAddress(self):
		"""DEPRECATED If the address type of Downstream Address TLV is set to ipv4Numbered, it signifies the numbered Interface Address. This takes value in ip address format.

		Returns:
			str
		"""
		return self._get_attribute('onDemandCvNumberedDownstreamInterfaceAddress')
	@OnDemandCvNumberedDownstreamInterfaceAddress.setter
	def OnDemandCvNumberedDownstreamInterfaceAddress(self, value):
		self._set_attribute('onDemandCvNumberedDownstreamInterfaceAddress', value)

	@property
	def OnDemandCvPadTlvFirstOctet(self):
		"""DEPRECATED This signifies the value of first octet of Pad TLV. The possible values are copy or drop.

		Returns:
			str(drop|copy)
		"""
		return self._get_attribute('onDemandCvPadTlvFirstOctet')
	@OnDemandCvPadTlvFirstOctet.setter
	def OnDemandCvPadTlvFirstOctet(self, value):
		self._set_attribute('onDemandCvPadTlvFirstOctet', value)

	@property
	def OnDemandCvPadTlvLength(self):
		"""DEPRECATED This signifies the inclusion of Pad TLV length in On Demand CV message.

		Returns:
			number
		"""
		return self._get_attribute('onDemandCvPadTlvLength')
	@OnDemandCvPadTlvLength.setter
	def OnDemandCvPadTlvLength(self, value):
		self._set_attribute('onDemandCvPadTlvLength', value)

	@property
	def OnDemandCvTosByte(self):
		"""DEPRECATED If channel type is set ip-udp-Gach, this signifies the value of Tos Byte field within Reply TOS Byte TLV, included in on demand cv messages.

		Returns:
			number
		"""
		return self._get_attribute('onDemandCvTosByte')
	@OnDemandCvTosByte.setter
	def OnDemandCvTosByte(self, value):
		self._set_attribute('onDemandCvTosByte', value)

	@property
	def OnDemandCvUnnumberedDownstreamInterfaceAddress(self):
		"""DEPRECATED If the address type of Downstream Address TLV is set to ipv4Unnumbered, this signifies the unnumbered Interface Address. This takes value in integer format. The max value can be 4294967295.

		Returns:
			number
		"""
		return self._get_attribute('onDemandCvUnnumberedDownstreamInterfaceAddress')
	@OnDemandCvUnnumberedDownstreamInterfaceAddress.setter
	def OnDemandCvUnnumberedDownstreamInterfaceAddress(self, value):
		self._set_attribute('onDemandCvUnnumberedDownstreamInterfaceAddress', value)

	@property
	def Periodicity(self):
		"""DEPRECATED This signifies the periodicity of the alarm.

		Returns:
			number
		"""
		return self._get_attribute('periodicity')
	@Periodicity.setter
	def Periodicity(self, value):
		self._set_attribute('periodicity', value)

	@property
	def PwStatusClearLabelTtl(self):
		"""DEPRECATED This signifies the PW status clear label Ttl.

		Returns:
			number
		"""
		return self._get_attribute('pwStatusClearLabelTtl')
	@PwStatusClearLabelTtl.setter
	def PwStatusClearLabelTtl(self, value):
		self._set_attribute('pwStatusClearLabelTtl', value)

	@property
	def PwStatusClearTransmitInterval(self):
		"""DEPRECATED This signifies the transmit interval in seconds.

		Returns:
			number
		"""
		return self._get_attribute('pwStatusClearTransmitInterval')
	@PwStatusClearTransmitInterval.setter
	def PwStatusClearTransmitInterval(self, value):
		self._set_attribute('pwStatusClearTransmitInterval', value)

	@property
	def PwStatusCode(self):
		"""DEPRECATED This signifies the selecting of the relevant option from the drop-down on the right hand side.

		Returns:
			number
		"""
		return self._get_attribute('pwStatusCode')
	@PwStatusCode.setter
	def PwStatusCode(self, value):
		self._set_attribute('pwStatusCode', value)

	@property
	def PwStatusFaultLabelTtl(self):
		"""DEPRECATED This signifies the TTL value to be set in the PW label header while sending out PW Status message.

		Returns:
			number
		"""
		return self._get_attribute('pwStatusFaultLabelTtl')
	@PwStatusFaultLabelTtl.setter
	def PwStatusFaultLabelTtl(self, value):
		self._set_attribute('pwStatusFaultLabelTtl', value)

	@property
	def PwStatusFaultTransmitInterval(self):
		"""DEPRECATED This signifies the PW Status Fault Transmit Interval in seconds.

		Returns:
			number
		"""
		return self._get_attribute('pwStatusFaultTransmitInterval')
	@PwStatusFaultTransmitInterval.setter
	def PwStatusFaultTransmitInterval(self, value):
		self._set_attribute('pwStatusFaultTransmitInterval', value)

	def update(self, AlarmTrigger=None, AlarmType=None, ApsTriggerType=None, CccvPauseTriggerOption=None, CccvResumeTriggerOption=None, ChangeSessionParameters=None, ClearMisconnectivityDefect=None, CounterType=None, DmInterval=None, DmIterations=None, DmMode=None, DmPadLen=None, DmRequestPaddedReply=None, DmTimeFormat=None, DmTrafficClass=None, DmType=None, EnableAlarm=None, EnableAlarmAis=None, EnableAlarmFastClear=None, EnableAlarmLck=None, EnableAlarmSetLdi=None, EnableApsTrigger=None, EnableCccvPause=None, EnableCccvResume=None, EnableDmTrigger=None, EnableLmTrigger=None, EnableLspPing=None, EnableLspPingFecStackValidation=None, EnableLspPingValidateReversePath=None, EnableLspTraceRoute=None, EnableLspTraceRouteFecStackValidation=None, EnablePwStatusClear=None, EnablePwStatusFault=None, LastDmResponseTimeout=None, LastLmResponseTimeout=None, LmInitialRxValue=None, LmInitialTxValue=None, LmInterval=None, LmIterations=None, LmMode=None, LmRxStep=None, LmTrafficClass=None, LmTxStep=None, LmType=None, LspPingEncapsulationType=None, LspPingResponseTimeout=None, LspPingTtlValue=None, LspTraceRouteEncapsulationType=None, LspTraceRouteResponseTimeout=None, LspTraceRouteTtlLimit=None, MinRxInterval=None, MinTxInterval=None, MisconnectivityDefect=None, MisconnectivityDefectOption=None, OnDemandCvDownstreamAddressType=None, OnDemandCvDownstreamIpAddress=None, OnDemandCvDsIflag=None, OnDemandCvDsNflag=None, OnDemandCvEgressIfNumber=None, OnDemandCvIncludeDestinationIdentifierTlv=None, OnDemandCvIncludeDetailedDownstreamMappingTlv=None, OnDemandCvIncludeDownstreamMappingTlv=None, OnDemandCvIncludePadTlv=None, OnDemandCvIncludeReplyTosByteTlv=None, OnDemandCvIncludeSourceIdentifierTlv=None, OnDemandCvIngressIfNumber=None, OnDemandCvNumberedDownstreamInterfaceAddress=None, OnDemandCvPadTlvFirstOctet=None, OnDemandCvPadTlvLength=None, OnDemandCvTosByte=None, OnDemandCvUnnumberedDownstreamInterfaceAddress=None, Periodicity=None, PwStatusClearLabelTtl=None, PwStatusClearTransmitInterval=None, PwStatusCode=None, PwStatusFaultLabelTtl=None, PwStatusFaultTransmitInterval=None):
		"""Updates a child instance of learnedInformation on the server.

		Args:
			AlarmTrigger (str(clear|start)): This signifies the alarm trigger. Possible values include Clear and Start.
			AlarmType (str(ietf|y1731)): This signifies the alarm type. Possible values include IETF and Y.1731.
			ApsTriggerType (str(clear|forcedSwitch|manualSwitchToProtect|manualSwitchToWorking|lockout|exercise|freeze)): This signifies the Trigger type. Possible values include Clear, Exercise, Forced Switch, Freeze, Lockout, Manual Switch To Protect and Manual Switch To Working.
			CccvPauseTriggerOption (str(tx|rx|txRx)): This signifies the cccv pause trigger option. Possible values include TX, RX and TXRX.
			CccvResumeTriggerOption (str(tx|rx|txRx)): This signifies the cccv resume trigger option. Possible values include Tx, Rx and TxRx.
			ChangeSessionParameters (bool): This specifies the minimum receive interval of cc messages in millisecond, at the source side that the user intends to set on the fly.
			ClearMisconnectivityDefect (bool): If set true all the misconnectivity defects that have been triggered earlier with any type gets cleared.
			CounterType (str(32Bit|64Bit)): This signifies the LM Counter Type. Possible values include 32 Bit (default) and 64 Bit.
			DmInterval (number): This signifies the DM interval in milliseconds.
			DmIterations (number): This signifies the total number of DM queries to be sent.
			DmMode (str(noResponseExpected|responseExpected)): This signifies the DM mode. The possible values include Response Expected and No Response Expected.
			DmPadLen (number): This signifies the DM pad length.
			DmRequestPaddedReply (bool): This signifies the DM request as a padded reply.
			DmTimeFormat (str(ieee|ntp)): This signifies the DM time format. The possible values include IEEE and NTP.
			DmTrafficClass (number): This signifies the DM traffic class value.
			DmType (str(ietf|y1731)): This signifies the DM Type. Possible values include IETF and Y.1731.
			EnableAlarm (bool): This signifies the enablement of the Alarm and the fields under it.
			EnableAlarmAis (bool): This signifies the enablement of the Alarm AIS.
			EnableAlarmFastClear (bool): Clears the Alarm State in 10 seconds
			EnableAlarmLck (bool): This signifies the enablement of the Alarm lck.
			EnableAlarmSetLdi (bool): This signifies the enablement of the Alarm Set LDI.
			EnableApsTrigger (bool): This signifies the enablement of APS trigger.
			EnableCccvPause (bool): This signifies the enabling of CCCV Pause.
			EnableCccvResume (bool): This signifies the enablement of CCCV Resume.
			EnableDmTrigger (bool): This signifies the enablement of the DM trigger.
			EnableLmTrigger (bool): This signifies the enablement of the LM trigger.
			EnableLspPing (bool): This signifies the enablement of the LSP Ping.
			EnableLspPingFecStackValidation (bool): This signifies the enablement of the FEC Stack Validation.
			EnableLspPingValidateReversePath (bool): If true validate reverse path bit is set in lsp ping message.
			EnableLspTraceRoute (bool): This signifies the enablement of the lsp traceroute.
			EnableLspTraceRouteFecStackValidation (bool): This signifies the enablement of the FEC Stack Validation.
			EnablePwStatusClear (bool): This signifies the enablement of the PW Status Clear and the fields under it.
			EnablePwStatusFault (bool): This signifies the enablement of the PW Status Fault.
			LastDmResponseTimeout (number): This signifies the last DM Response Timeout.
			LastLmResponseTimeout (number): This signifies the last LM response timeout.
			LmInitialRxValue (number): This signifies the LM Initial Rx value.
			LmInitialTxValue (number): This signifies the LM Initial Tx value.
			LmInterval (number): This signifies the LM interval in milliseconds.
			LmIterations (number): This signifies the number of LM queries to be sent.
			LmMode (str(responseExpected|noResponseExpected)): This signifies the LM mode. Possible values include Response Expected and No Response Expected.
			LmRxStep (number): This signifies the LM Rx step value.
			LmTrafficClass (number): This signifies the LM Traffic Class.
			LmTxStep (number): This signifies the LM Tx Step value.
			LmType (str(ietf|y1731)): This signifies the LM type. The possible values include IETF and Y.1731.
			LspPingEncapsulationType (str(GAch|UDP over IP over GAch)): This signifies the encapsulation type with which the lsp ping request message will be sent out. The possible values include UDP-IP-GAch and GAch.
			LspPingResponseTimeout (number): This signifies the response timeout in milliseconds.
			LspPingTtlValue (number): This signifies the LSP Ping Ttl value.
			LspTraceRouteEncapsulationType (str(GAch|UDP over IP over GAch)): This signifies the encapsulation type with which the Trace route request message will be sen out. The possible values include UDP-IP-GAch and GAch.
			LspTraceRouteResponseTimeout (number): This signifies the response timeout in milliseconds.
			LspTraceRouteTtlLimit (number): This signifies the max TTL till which the Echo Request will be sent out as part of trace route process.
			MinRxInterval (str(10|100|1000|10000|3.33|60000|600000)): This signifies the minimum receive interval of cc messages in millisecond, at the source side that the user intends to set on the fly.
			MinTxInterval (str(10|100|1000|10000|3.33|60000|600000)): This signifies the learned information minimum transmit interval, in milliseconds. This specifies the minimum transmit interval of cc messages in millisecond, at the source side that the user intends to set on the fly.
			MisconnectivityDefect (bool): To enable misconnectivity defect on the fly by changing LSP/PW MEP/MEG Id parameter or Your Discriminator on the source side.
			MisconnectivityDefectOption (str(unexpectedMepId|unexpectedYourDiscriminator)): To enable misconnectivity defect on the fly by changing LSP/PW MEP/MEG Id parameter or Your Discriminator on the source side.
			OnDemandCvDownstreamAddressType (str(ipv4Numbered|ipv4Unnumbered|nonIp)): This signifies the Address Type of the Downstream or Detailed Downstream Mapping TLV. This can be of three types.
			OnDemandCvDownstreamIpAddress (str): This signifies the inclusion of the IP address in Downstream or Detailed Downstream Mapping TLV. This takes input in ip address format.
			OnDemandCvDsIflag (bool): This signifies the setting of I bit in the DS Flag of Downstream or Detailed Downstream Mapping TLV.
			OnDemandCvDsNflag (bool): If set true, N bit is set in the DS Flag of Downstream or Detailed Downstream Mapping TLV.
			OnDemandCvEgressIfNumber (number): This signifies the Egress If Number, if address type of Downstream or Detailed Downstream Mapping TLV is set to nonIP.
			OnDemandCvIncludeDestinationIdentifierTlv (bool): If channel type is set to GAch, this signifies the inclusion of Destination Identifier TLV in the On Demand CV message. Possible values are true or false.
			OnDemandCvIncludeDetailedDownstreamMappingTlv (bool): This signifies the inclusion of the Detailed Downstream Mapping TLV in on demand cv message. Possible values are true or false.
			OnDemandCvIncludeDownstreamMappingTlv (bool): This signifies the inclusion of Downstream Mapping TLV in on demand cv messages.
			OnDemandCvIncludePadTlv (bool): This signifies the inclusion of Pad TLV in on demand cv messages (ping or traceroute).
			OnDemandCvIncludeReplyTosByteTlv (bool): This signifies the inclusion of Reply Tos Byte TLV in on demand cv messages, if channel type is configured ip-udp-gach.
			OnDemandCvIncludeSourceIdentifierTlv (bool): If channel type is set to GAch, this signifies the inclusion of Source Identifier TLV in the On Demand CV message. Possible values are true or false.
			OnDemandCvIngressIfNumber (number): This signifies the Ingress If Number, if address type of Downstream or Detailed Downstream Mapping TLV is set to nonIP.
			OnDemandCvNumberedDownstreamInterfaceAddress (str): If the address type of Downstream Address TLV is set to ipv4Numbered, it signifies the numbered Interface Address. This takes value in ip address format.
			OnDemandCvPadTlvFirstOctet (str(drop|copy)): This signifies the value of first octet of Pad TLV. The possible values are copy or drop.
			OnDemandCvPadTlvLength (number): This signifies the inclusion of Pad TLV length in On Demand CV message.
			OnDemandCvTosByte (number): If channel type is set ip-udp-Gach, this signifies the value of Tos Byte field within Reply TOS Byte TLV, included in on demand cv messages.
			OnDemandCvUnnumberedDownstreamInterfaceAddress (number): If the address type of Downstream Address TLV is set to ipv4Unnumbered, this signifies the unnumbered Interface Address. This takes value in integer format. The max value can be 4294967295.
			Periodicity (number): This signifies the periodicity of the alarm.
			PwStatusClearLabelTtl (number): This signifies the PW status clear label Ttl.
			PwStatusClearTransmitInterval (number): This signifies the transmit interval in seconds.
			PwStatusCode (number): This signifies the selecting of the relevant option from the drop-down on the right hand side.
			PwStatusFaultLabelTtl (number): This signifies the TTL value to be set in the PW label header while sending out PW Status message.
			PwStatusFaultTransmitInterval (number): This signifies the PW Status Fault Transmit Interval in seconds.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def ClearRecordsForTrigger(self):
		"""Executes the clearRecordsForTrigger operation on the server.

		This option is used to clear the selected learned information using the command addRecordForTrigger

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('clearRecordsForTrigger', payload=payload, response_object=None)

	def RefreshLearnedInformation(self):
		"""Executes the refreshLearnedInformation operation on the server.

		This signifies the refreshing of the learned information of MPLSTP router.

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('refreshLearnedInformation', payload=payload, response_object=None)

	def Trigger(self):
		"""Executes the trigger operation on the server.

		This signifies the learned info trigger settings.

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('trigger', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class LearnedInformation(Base):
	"""The LearnedInformation class encapsulates a required learnedInformation node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the LearnedInformation property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'learnedInformation'

	def __init__(self, parent):
		super(LearnedInformation, self).__init__(parent)

	@property
	def Ipv4Multicast(self):
		"""An instance of the Ipv4Multicast class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.ipv4multicast.Ipv4Multicast)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.ipv4multicast import Ipv4Multicast
		return Ipv4Multicast(self)

	@property
	def Ipv4Prefixes(self):
		"""An instance of the Ipv4Prefixes class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.ipv4prefixes.Ipv4Prefixes)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.ipv4prefixes import Ipv4Prefixes
		return Ipv4Prefixes(self)

	@property
	def Ipv6Multicast(self):
		"""An instance of the Ipv6Multicast class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.ipv6multicast.Ipv6Multicast)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.ipv6multicast import Ipv6Multicast
		return Ipv6Multicast(self)

	@property
	def Ipv6Prefixes(self):
		"""An instance of the Ipv6Prefixes class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.ipv6prefixes.Ipv6Prefixes)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.ipv6prefixes import Ipv6Prefixes
		return Ipv6Prefixes(self)

	@property
	def MacMulticast(self):
		"""An instance of the MacMulticast class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.macmulticast.MacMulticast)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.macmulticast import MacMulticast
		return MacMulticast(self)

	@property
	def RBridges(self):
		"""An instance of the RBridges class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.rbridges.RBridges)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.rbridges import RBridges
		return RBridges(self)

	@property
	def SpbRbridges(self):
		"""An instance of the SpbRbridges class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.spbrbridges.SpbRbridges)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.spbrbridges import SpbRbridges
		return SpbRbridges(self)

	@property
	def TrillMacUnicast(self):
		"""An instance of the TrillMacUnicast class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.trillmacunicast.TrillMacUnicast)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.trillmacunicast import TrillMacUnicast
		return TrillMacUnicast(self)

	@property
	def TrillOamPing(self):
		"""An instance of the TrillOamPing class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.trilloamping.TrillOamPing)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.trilloamping import TrillOamPing
		return TrillOamPing(self)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class SendgPtpSignalingParams(Base):
	"""The SendgPtpSignalingParams class encapsulates a required sendgPtpSignalingParams node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the SendgPtpSignalingParams property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'sendgPtpSignalingParams'

	def __init__(self, parent):
		super(SendgPtpSignalingParams, self).__init__(parent)

	@property
	def AnnounceInterval(self):
		"""Desired announceInterval

		Returns:
			str(doNotChange|initial|stop|v0_1_per_second_|v1_1_per_2_seconds_|v2_1_per_4_seconds_|v3_1_per_8_seconds_|v4_1_per_16_seconds_|v5_1_per_32_seconds_|v6_1_per_64_seconds_|v7_1_per_128_seconds_|v8_1_per_256_seconds_|v9_1_per_512_seconds_|vneg1_2_per_second_|vneg2_4_per_second_|vneg3_8_per_second_|vneg4_16_per_second_|vneg5_32_per_second_|vneg6_64_per_second_|vneg7_128_per_second_|vneg8_256_per_second_|vneg9_512_per_second_)
		"""
		return self._get_attribute('announceInterval')
	@AnnounceInterval.setter
	def AnnounceInterval(self, value):
		self._set_attribute('announceInterval', value)

	@property
	def ComputeNeighborPropDelay(self):
		"""computeNeighborPropDelay flag

		Returns:
			bool
		"""
		return self._get_attribute('computeNeighborPropDelay')
	@ComputeNeighborPropDelay.setter
	def ComputeNeighborPropDelay(self, value):
		self._set_attribute('computeNeighborPropDelay', value)

	@property
	def ComputeNeighborRateRatio(self):
		"""computeNeighborRateRatio flag

		Returns:
			bool
		"""
		return self._get_attribute('computeNeighborRateRatio')
	@ComputeNeighborRateRatio.setter
	def ComputeNeighborRateRatio(self, value):
		self._set_attribute('computeNeighborRateRatio', value)

	@property
	def LinkDelayInterval(self):
		"""Desired linkDelayInterval

		Returns:
			str(doNotChange|initial|stop|v0_1_per_second_|v1_1_per_2_seconds_|v2_1_per_4_seconds_|v3_1_per_8_seconds_|v4_1_per_16_seconds_|v5_1_per_32_seconds_|v6_1_per_64_seconds_|v7_1_per_128_seconds_|v8_1_per_256_seconds_|v9_1_per_512_seconds_|vneg1_2_per_second_|vneg2_4_per_second_|vneg3_8_per_second_|vneg4_16_per_second_|vneg5_32_per_second_|vneg6_64_per_second_|vneg7_128_per_second_|vneg8_256_per_second_|vneg9_512_per_second_)
		"""
		return self._get_attribute('linkDelayInterval')
	@LinkDelayInterval.setter
	def LinkDelayInterval(self, value):
		self._set_attribute('linkDelayInterval', value)

	@property
	def TimeSyncInterval(self):
		"""Desired timeSyncInterval

		Returns:
			str(doNotChange|initial|stop|v0_1_per_second_|v1_1_per_2_seconds_|v2_1_per_4_seconds_|v3_1_per_8_seconds_|v4_1_per_16_seconds_|v5_1_per_32_seconds_|v6_1_per_64_seconds_|v7_1_per_128_seconds_|v8_1_per_256_seconds_|v9_1_per_512_seconds_|vneg1_2_per_second_|vneg2_4_per_second_|vneg3_8_per_second_|vneg4_16_per_second_|vneg5_32_per_second_|vneg6_64_per_second_|vneg7_128_per_second_|vneg8_256_per_second_|vneg9_512_per_second_)
		"""
		return self._get_attribute('timeSyncInterval')
	@TimeSyncInterval.setter
	def TimeSyncInterval(self, value):
		self._set_attribute('timeSyncInterval', value)

	def update(self, AnnounceInterval=None, ComputeNeighborPropDelay=None, ComputeNeighborRateRatio=None, LinkDelayInterval=None, TimeSyncInterval=None):
		"""Updates a child instance of sendgPtpSignalingParams on the server.

		Args:
			AnnounceInterval (str(doNotChange|initial|stop|v0_1_per_second_|v1_1_per_2_seconds_|v2_1_per_4_seconds_|v3_1_per_8_seconds_|v4_1_per_16_seconds_|v5_1_per_32_seconds_|v6_1_per_64_seconds_|v7_1_per_128_seconds_|v8_1_per_256_seconds_|v9_1_per_512_seconds_|vneg1_2_per_second_|vneg2_4_per_second_|vneg3_8_per_second_|vneg4_16_per_second_|vneg5_32_per_second_|vneg6_64_per_second_|vneg7_128_per_second_|vneg8_256_per_second_|vneg9_512_per_second_)): Desired announceInterval
			ComputeNeighborPropDelay (bool): computeNeighborPropDelay flag
			ComputeNeighborRateRatio (bool): computeNeighborRateRatio flag
			LinkDelayInterval (str(doNotChange|initial|stop|v0_1_per_second_|v1_1_per_2_seconds_|v2_1_per_4_seconds_|v3_1_per_8_seconds_|v4_1_per_16_seconds_|v5_1_per_32_seconds_|v6_1_per_64_seconds_|v7_1_per_128_seconds_|v8_1_per_256_seconds_|v9_1_per_512_seconds_|vneg1_2_per_second_|vneg2_4_per_second_|vneg3_8_per_second_|vneg4_16_per_second_|vneg5_32_per_second_|vneg6_64_per_second_|vneg7_128_per_second_|vneg8_256_per_second_|vneg9_512_per_second_)): Desired linkDelayInterval
			TimeSyncInterval (str(doNotChange|initial|stop|v0_1_per_second_|v1_1_per_2_seconds_|v2_1_per_4_seconds_|v3_1_per_8_seconds_|v4_1_per_16_seconds_|v5_1_per_32_seconds_|v6_1_per_64_seconds_|v7_1_per_128_seconds_|v8_1_per_256_seconds_|v9_1_per_512_seconds_|vneg1_2_per_second_|vneg2_4_per_second_|vneg3_8_per_second_|vneg4_16_per_second_|vneg5_32_per_second_|vneg6_64_per_second_|vneg7_128_per_second_|vneg8_256_per_second_|vneg9_512_per_second_)): Desired timeSyncInterval

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def SendgPtpSignaling(self):
		"""Executes the sendgPtpSignaling operation on the server.

		Send Signaling messages for the selected PTP IEEE 802.1AS sessions.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('sendgPtpSignaling', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class FlowSet(Base):
	"""The FlowSet class encapsulates a system managed flowSet node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the FlowSet property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'flowSet'

	def __init__(self, parent):
		super(FlowSet, self).__init__(parent)

	@property
	def FlowProfile(self):
		"""An instance of the FlowProfile class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.flowprofile.FlowProfile)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.flowprofile import FlowProfile
		return FlowProfile(self)._select()

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def Cookie(self):
		"""Cookie of the flow entry that was looked up. This is the opaque controller-issued identifier.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('cookie')

	@property
	def CookieMask(self):
		"""The mask used to restrict the cookie bits.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('cookieMask')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def FlowAdvertise(self):
		"""If selected, the flows are advertised by the OF Channel.

		Returns:
			bool
		"""
		return self._get_attribute('flowAdvertise')
	@FlowAdvertise.setter
	def FlowAdvertise(self, value):
		self._set_attribute('flowAdvertise', value)

	@property
	def FlowFlags(self):
		"""Allows to configure the Flow Flags. Options are: 1) Send Flow Removed 2) Check Overlap 3) Reset Counts 4) No Packet Count 5) No Byte Count

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('flowFlags')

	@property
	def FlowMatchType(self):
		"""The type of match to be configured. Options include the following: 1) Strict 2) Loose

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('flowMatchType')

	@property
	def FlowSetId(self):
		"""Specify the controller Flow Set identifier.

		Returns:
			str
		"""
		return self._get_attribute('flowSetId')
	@FlowSetId.setter
	def FlowSetId(self, value):
		self._set_attribute('flowSetId', value)

	@property
	def HardTimeout(self):
		"""The inactive time in seconds after which the Flow range will hard timeout and close.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('hardTimeout')

	@property
	def IdleTimeout(self):
		"""The inactive time in seconds after which the Flow range will timeout and become idle.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('idleTimeout')

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def NumberOfFlows(self):
		"""The number of flows to be configured for the controller table.

		Returns:
			number
		"""
		return self._get_attribute('numberOfFlows')
	@NumberOfFlows.setter
	def NumberOfFlows(self, value):
		self._set_attribute('numberOfFlows', value)

	@property
	def Priority(self):
		"""The priority level for the Flow Range.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('priority')

	def update(self, FlowAdvertise=None, FlowSetId=None, Name=None, NumberOfFlows=None):
		"""Updates a child instance of flowSet on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			FlowAdvertise (bool): If selected, the flows are advertised by the OF Channel.
			FlowSetId (str): Specify the controller Flow Set identifier.
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NumberOfFlows (number): The number of flows to be configured for the controller table.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def find(self, Count=None, DescriptiveName=None, FlowAdvertise=None, FlowSetId=None, Name=None, NumberOfFlows=None):
		"""Finds and retrieves flowSet data from the server.

		All named parameters support regex and can be used to selectively retrieve flowSet data from the server.
		By default the find method takes no parameters and will retrieve all flowSet data from the server.

		Args:
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			FlowAdvertise (bool): If selected, the flows are advertised by the OF Channel.
			FlowSetId (str): Specify the controller Flow Set identifier.
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NumberOfFlows (number): The number of flows to be configured for the controller table.

		Returns:
			self: This instance with matching flowSet data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of flowSet data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the flowSet data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, Active=None, Cookie=None, CookieMask=None, FlowFlags=None, FlowMatchType=None, HardTimeout=None, IdleTimeout=None, Priority=None):
		"""Base class infrastructure that gets a list of flowSet device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Active (str): optional regex of active
			Cookie (str): optional regex of cookie
			CookieMask (str): optional regex of cookieMask
			FlowFlags (str): optional regex of flowFlags
			FlowMatchType (str): optional regex of flowMatchType
			HardTimeout (str): optional regex of hardTimeout
			IdleTimeout (str): optional regex of idleTimeout
			Priority (str): optional regex of priority

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Error(Base):
	"""The Error class encapsulates a system managed error node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Error property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'error'

	def __init__(self, parent):
		super(Error, self).__init__(parent)

	@property
	def Instance(self):
		"""An instance of the Instance class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.apperrors.error.instance.instance.Instance)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.apperrors.error.instance.instance import Instance
		return Instance(self)

	@property
	def Description(self):
		"""The description of the error

		Returns:
			str
		"""
		return self._get_attribute('description')

	@property
	def ErrorCode(self):
		"""The error code of the error

		Returns:
			number
		"""
		return self._get_attribute('errorCode')

	@property
	def ErrorLevel(self):
		"""The error level of the error

		Returns:
			str(kAnalysis|kCount|kError|kMessage|kWarning)
		"""
		return self._get_attribute('errorLevel')

	@property
	def InstanceCount(self):
		"""The number of instances of the error

		Returns:
			number
		"""
		return self._get_attribute('instanceCount')

	@property
	def LastModified(self):
		"""

		Returns:
			str
		"""
		return self._get_attribute('lastModified')

	@property
	def Name(self):
		"""The name of the error

		Returns:
			str
		"""
		return self._get_attribute('name')

	@property
	def Provider(self):
		"""The error provider of the error

		Returns:
			str
		"""
		return self._get_attribute('provider')

	@property
	def SourceColumns(self):
		"""If the error content originated from an xml meta file, these are the source column names if any for this error.

		Returns:
			list(str)
		"""
		return self._get_attribute('sourceColumns')

	@property
	def SourceColumnsDisplayName(self):
		"""

		Returns:
			list(str)
		"""
		return self._get_attribute('sourceColumnsDisplayName')

	def find(self, Description=None, ErrorCode=None, ErrorLevel=None, InstanceCount=None, LastModified=None, Name=None, Provider=None, SourceColumns=None, SourceColumnsDisplayName=None):
		"""Finds and retrieves error data from the server.

		All named parameters support regex and can be used to selectively retrieve error data from the server.
		By default the find method takes no parameters and will retrieve all error data from the server.

		Args:
			Description (str): The description of the error
			ErrorCode (number): The error code of the error
			ErrorLevel (str(kAnalysis|kCount|kError|kMessage|kWarning)): The error level of the error
			InstanceCount (number): The number of instances of the error
			LastModified (str): 
			Name (str): The name of the error
			Provider (str): The error provider of the error
			SourceColumns (list(str)): If the error content originated from an xml meta file, these are the source column names if any for this error.
			SourceColumnsDisplayName (list(str)): 

		Returns:
			self: This instance with matching error data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of error data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the error data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Ipv4mpls(Base):
	"""The Ipv4mpls class encapsulates a system managed ipv4mpls node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Ipv4mpls property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'ipv4mpls'

	def __init__(self, parent):
		super(Ipv4mpls, self).__init__(parent)

	@property
	def AsPath(self):
		"""Indicates the local IP address of the BGP router.

		Returns:
			str
		"""
		return self._get_attribute('asPath')

	@property
	def BlockOffset(self):
		"""The label block offset (VBO) is the value used to help define this specific label block uniquely as a subset of all of the possible labels.

		Returns:
			number
		"""
		return self._get_attribute('blockOffset')

	@property
	def BlockSize(self):
		"""The size of the label block, in bytes.

		Returns:
			number
		"""
		return self._get_attribute('blockSize')

	@property
	def ControlWordEnabled(self):
		"""If true, the route label uses a control word, as part of the extended community information. (One of the control flags.)

		Returns:
			bool
		"""
		return self._get_attribute('controlWordEnabled')

	@property
	def IpPrefix(self):
		"""The route IP prefix.

		Returns:
			str
		"""
		return self._get_attribute('ipPrefix')

	@property
	def LabelBase(self):
		"""The first label to be assigned to the FEC.

		Returns:
			number
		"""
		return self._get_attribute('labelBase')

	@property
	def LocalPreference(self):
		"""Indicates the value of the local preference attribute.

		Returns:
			number
		"""
		return self._get_attribute('localPreference')

	@property
	def MaxLabel(self):
		"""The last label to use.

		Returns:
			number
		"""
		return self._get_attribute('maxLabel')

	@property
	def MultiExitDiscriminator(self):
		"""A metric field of the route file.

		Returns:
			number
		"""
		return self._get_attribute('multiExitDiscriminator')

	@property
	def Neighbor(self):
		"""The descriptive identifier for the BGP neighbor.

		Returns:
			str
		"""
		return self._get_attribute('neighbor')

	@property
	def NextHop(self):
		"""A 4-octet IP address which indicates the next hop.

		Returns:
			str
		"""
		return self._get_attribute('nextHop')

	@property
	def OriginType(self):
		"""An indication of where the route entry originated.

		Returns:
			str
		"""
		return self._get_attribute('originType')

	@property
	def PrefixLength(self):
		"""The length of the route IP prefix, in bytes.

		Returns:
			number
		"""
		return self._get_attribute('prefixLength')

	@property
	def RouteDistinguisher(self):
		"""The route distinguisher for the route, for use with IPv4 and IPv6 MPLS VPN address types.

		Returns:
			str
		"""
		return self._get_attribute('routeDistinguisher')

	@property
	def SeqDeliveryEnabled(self):
		"""Indicates if sequential delivery is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('seqDeliveryEnabled')

	@property
	def SiteId(self):
		"""The site ID.

		Returns:
			number
		"""
		return self._get_attribute('siteId')

	def find(self, AsPath=None, BlockOffset=None, BlockSize=None, ControlWordEnabled=None, IpPrefix=None, LabelBase=None, LocalPreference=None, MaxLabel=None, MultiExitDiscriminator=None, Neighbor=None, NextHop=None, OriginType=None, PrefixLength=None, RouteDistinguisher=None, SeqDeliveryEnabled=None, SiteId=None):
		"""Finds and retrieves ipv4mpls data from the server.

		All named parameters support regex and can be used to selectively retrieve ipv4mpls data from the server.
		By default the find method takes no parameters and will retrieve all ipv4mpls data from the server.

		Args:
			AsPath (str): Indicates the local IP address of the BGP router.
			BlockOffset (number): The label block offset (VBO) is the value used to help define this specific label block uniquely as a subset of all of the possible labels.
			BlockSize (number): The size of the label block, in bytes.
			ControlWordEnabled (bool): If true, the route label uses a control word, as part of the extended community information. (One of the control flags.)
			IpPrefix (str): The route IP prefix.
			LabelBase (number): The first label to be assigned to the FEC.
			LocalPreference (number): Indicates the value of the local preference attribute.
			MaxLabel (number): The last label to use.
			MultiExitDiscriminator (number): A metric field of the route file.
			Neighbor (str): The descriptive identifier for the BGP neighbor.
			NextHop (str): A 4-octet IP address which indicates the next hop.
			OriginType (str): An indication of where the route entry originated.
			PrefixLength (number): The length of the route IP prefix, in bytes.
			RouteDistinguisher (str): The route distinguisher for the route, for use with IPv4 and IPv6 MPLS VPN address types.
			SeqDeliveryEnabled (bool): Indicates if sequential delivery is enabled.
			SiteId (number): The site ID.

		Returns:
			self: This instance with matching ipv4mpls data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of ipv4mpls data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the ipv4mpls data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Traffic(Base):
	"""The Traffic class encapsulates a required traffic node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Traffic property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'traffic'

	def __init__(self, parent):
		super(Traffic, self).__init__(parent)

	@property
	def DynamicFrameSize(self):
		"""An instance of the DynamicFrameSize class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.dynamicframesize.dynamicframesize.DynamicFrameSize)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.dynamicframesize.dynamicframesize import DynamicFrameSize
		return DynamicFrameSize(self)

	@property
	def DynamicRate(self):
		"""An instance of the DynamicRate class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.dynamicrate.dynamicrate.DynamicRate)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.dynamicrate.dynamicrate import DynamicRate
		return DynamicRate(self)

	@property
	def EgressOnlyTracking(self):
		"""An instance of the EgressOnlyTracking class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.egressonlytracking.egressonlytracking.EgressOnlyTracking)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.egressonlytracking.egressonlytracking import EgressOnlyTracking
		return EgressOnlyTracking(self)

	@property
	def ProtocolTemplate(self):
		"""An instance of the ProtocolTemplate class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.protocoltemplate.protocoltemplate.ProtocolTemplate)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.protocoltemplate.protocoltemplate import ProtocolTemplate
		return ProtocolTemplate(self)

	@property
	def Statistics(self):
		"""An instance of the Statistics class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.statistics.Statistics)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.statistics import Statistics
		return Statistics(self)._select()

	@property
	def TrafficGroup(self):
		"""An instance of the TrafficGroup class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficgroup.trafficgroup.TrafficGroup)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficgroup.trafficgroup import TrafficGroup
		return TrafficGroup(self)

	@property
	def TrafficItem(self):
		"""An instance of the TrafficItem class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.trafficitem.TrafficItem)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.trafficitem import TrafficItem
		return TrafficItem(self)

	@property
	def AutoCorrectL4HeaderChecksums(self):
		"""This is used for Multis and Xdensity as checksum is not calculated correctly when change on the fly operations are performed. When this option is enabled IxOS uses 2 bytes before CRC, that way ensuring the checksum is correct when change on the fly operations are performed.

		Returns:
			bool
		"""
		return self._get_attribute('autoCorrectL4HeaderChecksums')
	@AutoCorrectL4HeaderChecksums.setter
	def AutoCorrectL4HeaderChecksums(self, value):
		self._set_attribute('autoCorrectL4HeaderChecksums', value)

	@property
	def CycleOffsetForScheduledStart(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('cycleOffsetForScheduledStart')
	@CycleOffsetForScheduledStart.setter
	def CycleOffsetForScheduledStart(self, value):
		self._set_attribute('cycleOffsetForScheduledStart', value)

	@property
	def CycleOffsetUnitForScheduledStart(self):
		"""

		Returns:
			str(microseconds|milliseconds|nanoseconds|seconds)
		"""
		return self._get_attribute('cycleOffsetUnitForScheduledStart')
	@CycleOffsetUnitForScheduledStart.setter
	def CycleOffsetUnitForScheduledStart(self, value):
		self._set_attribute('cycleOffsetUnitForScheduledStart', value)

	@property
	def CycleTimeForScheduledStart(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('cycleTimeForScheduledStart')
	@CycleTimeForScheduledStart.setter
	def CycleTimeForScheduledStart(self, value):
		self._set_attribute('cycleTimeForScheduledStart', value)

	@property
	def CycleTimeUnitForScheduledStart(self):
		"""

		Returns:
			str(microseconds|milliseconds|nanoseconds|seconds)
		"""
		return self._get_attribute('cycleTimeUnitForScheduledStart')
	@CycleTimeUnitForScheduledStart.setter
	def CycleTimeUnitForScheduledStart(self, value):
		self._set_attribute('cycleTimeUnitForScheduledStart', value)

	@property
	def DataPlaneJitterWindow(self):
		"""DEPRECATED Indicates the number of packets received during a time interval. This is used forcalculating the rate on the recieve side.

		Returns:
			str(0|10485760|1310720|167772160|20971520|2621440|335544320|41943040|5242880|671088640|83886080)
		"""
		return self._get_attribute('dataPlaneJitterWindow')
	@DataPlaneJitterWindow.setter
	def DataPlaneJitterWindow(self, value):
		self._set_attribute('dataPlaneJitterWindow', value)

	@property
	def DelayTimeForScheduledStart(self):
		"""DEPRECATED Delay Time For Scheduled Start Transmit in seconds

		Returns:
			number
		"""
		return self._get_attribute('delayTimeForScheduledStart')
	@DelayTimeForScheduledStart.setter
	def DelayTimeForScheduledStart(self, value):
		self._set_attribute('delayTimeForScheduledStart', value)

	@property
	def DestMacRetryCount(self):
		"""DEPRECATED The number of time to attempt to obtain the destination MAC address.

		Returns:
			number
		"""
		return self._get_attribute('destMacRetryCount')
	@DestMacRetryCount.setter
	def DestMacRetryCount(self, value):
		self._set_attribute('destMacRetryCount', value)

	@property
	def DestMacRetryDelay(self):
		"""DEPRECATED The number of seconds to wait between attempts to obtain the destination MAC address.

		Returns:
			number
		"""
		return self._get_attribute('destMacRetryDelay')
	@DestMacRetryDelay.setter
	def DestMacRetryDelay(self, value):
		self._set_attribute('destMacRetryDelay', value)

	@property
	def DetectMisdirectedOnAllPorts(self):
		"""DEPRECATED 

		Returns:
			bool
		"""
		return self._get_attribute('detectMisdirectedOnAllPorts')
	@DetectMisdirectedOnAllPorts.setter
	def DetectMisdirectedOnAllPorts(self, value):
		self._set_attribute('detectMisdirectedOnAllPorts', value)

	@property
	def DisplayMplsCurrentLabelValue(self):
		"""DEPRECATED Displays current label value for LSP Endpoints.

		Returns:
			bool
		"""
		return self._get_attribute('displayMplsCurrentLabelValue')
	@DisplayMplsCurrentLabelValue.setter
	def DisplayMplsCurrentLabelValue(self, value):
		self._set_attribute('displayMplsCurrentLabelValue', value)

	@property
	def ElapsedTransmitTime(self):
		"""DEPRECATED Specifies the amount of time traffic is running in milliseconds. If the traffic state is unapplied or errored then the transmit time will be 0.

		Returns:
			number
		"""
		return self._get_attribute('elapsedTransmitTime')

	@property
	def EnableDataIntegrityCheck(self):
		"""DEPRECATED If true, enable data integrity check.

		Returns:
			bool
		"""
		return self._get_attribute('enableDataIntegrityCheck')
	@EnableDataIntegrityCheck.setter
	def EnableDataIntegrityCheck(self, value):
		self._set_attribute('enableDataIntegrityCheck', value)

	@property
	def EnableDestMacRetry(self):
		"""DEPRECATED If true, enables the destination MAC address retry function.

		Returns:
			bool
		"""
		return self._get_attribute('enableDestMacRetry')
	@EnableDestMacRetry.setter
	def EnableDestMacRetry(self, value):
		self._set_attribute('enableDestMacRetry', value)

	@property
	def EnableEgressOnlyTracking(self):
		"""DEPRECATED This flags enables/disables egress only tracking on the quick flow group. In this mode only quick flow groups are supported, user will have only PGID stats and the packets will not contain any instrumentation block.

		Returns:
			bool
		"""
		return self._get_attribute('enableEgressOnlyTracking')
	@EnableEgressOnlyTracking.setter
	def EnableEgressOnlyTracking(self, value):
		self._set_attribute('enableEgressOnlyTracking', value)

	@property
	def EnableInstantaneousStatsSupport(self):
		"""DEPRECATED If true, enables instantaneous stats support

		Returns:
			bool
		"""
		return self._get_attribute('enableInstantaneousStatsSupport')
	@EnableInstantaneousStatsSupport.setter
	def EnableInstantaneousStatsSupport(self, value):
		self._set_attribute('enableInstantaneousStatsSupport', value)

	@property
	def EnableLagFlowBalancing(self):
		"""DEPRECATED 

		Returns:
			bool
		"""
		return self._get_attribute('enableLagFlowBalancing')
	@EnableLagFlowBalancing.setter
	def EnableLagFlowBalancing(self, value):
		self._set_attribute('enableLagFlowBalancing', value)

	@property
	def EnableMinFrameSize(self):
		"""DEPRECATED If true, IxNetwork will allow the stream to use smaller packet sizes. (In the case of IPv4 and Ethernet, 64 bytes will be allowed.) This is achieved by reducing the size of the instrumentation tag, which will be identified by receiving ports.

		Returns:
			bool
		"""
		return self._get_attribute('enableMinFrameSize')
	@EnableMinFrameSize.setter
	def EnableMinFrameSize(self, value):
		self._set_attribute('enableMinFrameSize', value)

	@property
	def EnableMulticastScalingFactor(self):
		"""DEPRECATED If true, traffic items with the Merged Destination Ranges option selected have be to manually regenerated by the user.

		Returns:
			bool
		"""
		return self._get_attribute('enableMulticastScalingFactor')
	@EnableMulticastScalingFactor.setter
	def EnableMulticastScalingFactor(self, value):
		self._set_attribute('enableMulticastScalingFactor', value)

	@property
	def EnableSequenceChecking(self):
		"""DEPRECATED If true, this field enables sequence checking. The default is false.

		Returns:
			bool
		"""
		return self._get_attribute('enableSequenceChecking')
	@EnableSequenceChecking.setter
	def EnableSequenceChecking(self, value):
		self._set_attribute('enableSequenceChecking', value)

	@property
	def EnableStaggeredStartDelay(self):
		"""DEPRECATED If checked, enables the staggered start delay function.

		Returns:
			bool
		"""
		return self._get_attribute('enableStaggeredStartDelay')
	@EnableStaggeredStartDelay.setter
	def EnableStaggeredStartDelay(self, value):
		self._set_attribute('enableStaggeredStartDelay', value)

	@property
	def EnableStaggeredTransmit(self):
		"""DEPRECATED If true, the start of transmit is staggered across ports. A 25-30 ms delay is introduced between the time one port begins transmitting and the time next port begins transmitting.

		Returns:
			bool
		"""
		return self._get_attribute('enableStaggeredTransmit')
	@EnableStaggeredTransmit.setter
	def EnableStaggeredTransmit(self, value):
		self._set_attribute('enableStaggeredTransmit', value)

	@property
	def EnableStreamOrdering(self):
		"""DEPRECATED If true, IxNetwork will allow stream ordering per RFC 2889.

		Returns:
			bool
		"""
		return self._get_attribute('enableStreamOrdering')
	@EnableStreamOrdering.setter
	def EnableStreamOrdering(self, value):
		self._set_attribute('enableStreamOrdering', value)

	@property
	def FrameOrderingMode(self):
		"""DEPRECATED If true, enables frame ordering.

		Returns:
			str(flowGroupSetup|none|peakLoading|RFC2889)
		"""
		return self._get_attribute('frameOrderingMode')
	@FrameOrderingMode.setter
	def FrameOrderingMode(self, value):
		self._set_attribute('frameOrderingMode', value)

	@property
	def GlobalStreamControl(self):
		"""DEPRECATED The Global Stream Control parameters.

		Returns:
			str(continuous|iterations)
		"""
		return self._get_attribute('globalStreamControl')
	@GlobalStreamControl.setter
	def GlobalStreamControl(self, value):
		self._set_attribute('globalStreamControl', value)

	@property
	def GlobalStreamControlIterations(self):
		"""DEPRECATED If true, the user can specify how many times each packet stream will be transmitted.

		Returns:
			number
		"""
		return self._get_attribute('globalStreamControlIterations')
	@GlobalStreamControlIterations.setter
	def GlobalStreamControlIterations(self, value):
		self._set_attribute('globalStreamControlIterations', value)

	@property
	def IsApplicationTrafficRunning(self):
		"""DEPRECATED If true, application traffic is running.

		Returns:
			bool
		"""
		return self._get_attribute('isApplicationTrafficRunning')

	@property
	def IsApplyOnTheFlyRequired(self):
		"""DEPRECATED 

		Returns:
			bool
		"""
		return self._get_attribute('isApplyOnTheFlyRequired')

	@property
	def IsTrafficRunning(self):
		"""DEPRECATED If true, non-application traffic is running.

		Returns:
			bool
		"""
		return self._get_attribute('isTrafficRunning')

	@property
	def LargeErrorThreshhold(self):
		"""DEPRECATED The user-configurable threshold value used to determine error levels for out-of-sequence, received packets.

		Returns:
			number
		"""
		return self._get_attribute('largeErrorThreshhold')
	@LargeErrorThreshhold.setter
	def LargeErrorThreshhold(self, value):
		self._set_attribute('largeErrorThreshhold', value)

	@property
	def LearningFrameSize(self):
		"""DEPRECATED Learns frame size

		Returns:
			number
		"""
		return self._get_attribute('learningFrameSize')
	@LearningFrameSize.setter
	def LearningFrameSize(self, value):
		self._set_attribute('learningFrameSize', value)

	@property
	def LearningFramesCount(self):
		"""DEPRECATED Learns frames count

		Returns:
			number
		"""
		return self._get_attribute('learningFramesCount')
	@LearningFramesCount.setter
	def LearningFramesCount(self, value):
		self._set_attribute('learningFramesCount', value)

	@property
	def LearningFramesRate(self):
		"""DEPRECATED Learns frames rate

		Returns:
			number
		"""
		return self._get_attribute('learningFramesRate')
	@LearningFramesRate.setter
	def LearningFramesRate(self, value):
		self._set_attribute('learningFramesRate', value)

	@property
	def MacChangeOnFly(self):
		"""DEPRECATED If true, enables IxNetwork's gratuitous ARP capability. When enabled, IxNetwork listens for gratuitous ARP messages from its neighbors.

		Returns:
			bool
		"""
		return self._get_attribute('macChangeOnFly')
	@MacChangeOnFly.setter
	def MacChangeOnFly(self, value):
		self._set_attribute('macChangeOnFly', value)

	@property
	def MaxTrafficGenerationQueries(self):
		"""DEPRECATED The maximum number of traffic generation queries. The default is 500.

		Returns:
			number
		"""
		return self._get_attribute('maxTrafficGenerationQueries')
	@MaxTrafficGenerationQueries.setter
	def MaxTrafficGenerationQueries(self, value):
		self._set_attribute('maxTrafficGenerationQueries', value)

	@property
	def MplsLabelLearningTimeout(self):
		"""DEPRECATED The MPLS label learning timeout in seconds. The default is 30 seconds.

		Returns:
			number
		"""
		return self._get_attribute('mplsLabelLearningTimeout')
	@MplsLabelLearningTimeout.setter
	def MplsLabelLearningTimeout(self, value):
		self._set_attribute('mplsLabelLearningTimeout', value)

	@property
	def PeakLoadingReplicationCount(self):
		"""DEPRECATED The peak loading replication count

		Returns:
			number
		"""
		return self._get_attribute('peakLoadingReplicationCount')
	@PeakLoadingReplicationCount.setter
	def PeakLoadingReplicationCount(self, value):
		self._set_attribute('peakLoadingReplicationCount', value)

	@property
	def PreventDataPlaneToCpu(self):
		"""DEPRECATED Prevent all data plane packets from being forwarded to Port CPU (disabling this option requires Port CPU reboot)

		Returns:
			bool
		"""
		return self._get_attribute('preventDataPlaneToCpu')
	@PreventDataPlaneToCpu.setter
	def PreventDataPlaneToCpu(self, value):
		self._set_attribute('preventDataPlaneToCpu', value)

	@property
	def RefreshLearnedInfoBeforeApply(self):
		"""DEPRECATED This field refreshes the learned information from the DUT.

		Returns:
			bool
		"""
		return self._get_attribute('refreshLearnedInfoBeforeApply')
	@RefreshLearnedInfoBeforeApply.setter
	def RefreshLearnedInfoBeforeApply(self, value):
		self._set_attribute('refreshLearnedInfoBeforeApply', value)

	@property
	def State(self):
		"""DEPRECATED Denotes the current state of traffic.

		Returns:
			str(error|locked|started|startedWaitingForStats|startedWaitingForStreams|stopped|stoppedWaitingForStats|txStopWatchExpected|unapplied)
		"""
		return self._get_attribute('state')

	@property
	def UseRfc5952(self):
		"""DEPRECATED Use RFC 5952 for formatting IPv6 addresses (:ffff:1.2.3.4)

		Returns:
			bool
		"""
		return self._get_attribute('useRfc5952')
	@UseRfc5952.setter
	def UseRfc5952(self, value):
		self._set_attribute('useRfc5952', value)

	@property
	def UseScheduledStartTransmit(self):
		"""DEPRECATED Use Scheduled Start Transmit

		Returns:
			bool
		"""
		return self._get_attribute('useScheduledStartTransmit')
	@UseScheduledStartTransmit.setter
	def UseScheduledStartTransmit(self, value):
		self._set_attribute('useScheduledStartTransmit', value)

	@property
	def UseTxRxSync(self):
		"""DEPRECATED If true, enables the transmit/receive port synchronization algorithm.

		Returns:
			bool
		"""
		return self._get_attribute('useTxRxSync')
	@UseTxRxSync.setter
	def UseTxRxSync(self, value):
		self._set_attribute('useTxRxSync', value)

	@property
	def WaitTime(self):
		"""DEPRECATED The time (in seconds) to wait after Stop Transmit before stopping Latency Measurement.

		Returns:
			number
		"""
		return self._get_attribute('waitTime')
	@WaitTime.setter
	def WaitTime(self, value):
		self._set_attribute('waitTime', value)

	def update(self, AutoCorrectL4HeaderChecksums=None, CycleOffsetForScheduledStart=None, CycleOffsetUnitForScheduledStart=None, CycleTimeForScheduledStart=None, CycleTimeUnitForScheduledStart=None, DataPlaneJitterWindow=None, DelayTimeForScheduledStart=None, DestMacRetryCount=None, DestMacRetryDelay=None, DetectMisdirectedOnAllPorts=None, DisplayMplsCurrentLabelValue=None, EnableDataIntegrityCheck=None, EnableDestMacRetry=None, EnableEgressOnlyTracking=None, EnableInstantaneousStatsSupport=None, EnableLagFlowBalancing=None, EnableMinFrameSize=None, EnableMulticastScalingFactor=None, EnableSequenceChecking=None, EnableStaggeredStartDelay=None, EnableStaggeredTransmit=None, EnableStreamOrdering=None, FrameOrderingMode=None, GlobalStreamControl=None, GlobalStreamControlIterations=None, LargeErrorThreshhold=None, LearningFrameSize=None, LearningFramesCount=None, LearningFramesRate=None, MacChangeOnFly=None, MaxTrafficGenerationQueries=None, MplsLabelLearningTimeout=None, PeakLoadingReplicationCount=None, PreventDataPlaneToCpu=None, RefreshLearnedInfoBeforeApply=None, UseRfc5952=None, UseScheduledStartTransmit=None, UseTxRxSync=None, WaitTime=None):
		"""Updates a child instance of traffic on the server.

		Args:
			AutoCorrectL4HeaderChecksums (bool): This is used for Multis and Xdensity as checksum is not calculated correctly when change on the fly operations are performed. When this option is enabled IxOS uses 2 bytes before CRC, that way ensuring the checksum is correct when change on the fly operations are performed.
			CycleOffsetForScheduledStart (number): 
			CycleOffsetUnitForScheduledStart (str(microseconds|milliseconds|nanoseconds|seconds)): 
			CycleTimeForScheduledStart (number): 
			CycleTimeUnitForScheduledStart (str(microseconds|milliseconds|nanoseconds|seconds)): 
			DataPlaneJitterWindow (str(0|10485760|1310720|167772160|20971520|2621440|335544320|41943040|5242880|671088640|83886080)): Indicates the number of packets received during a time interval. This is used forcalculating the rate on the recieve side.
			DelayTimeForScheduledStart (number): Delay Time For Scheduled Start Transmit in seconds
			DestMacRetryCount (number): The number of time to attempt to obtain the destination MAC address.
			DestMacRetryDelay (number): The number of seconds to wait between attempts to obtain the destination MAC address.
			DetectMisdirectedOnAllPorts (bool): 
			DisplayMplsCurrentLabelValue (bool): Displays current label value for LSP Endpoints.
			EnableDataIntegrityCheck (bool): If true, enable data integrity check.
			EnableDestMacRetry (bool): If true, enables the destination MAC address retry function.
			EnableEgressOnlyTracking (bool): This flags enables/disables egress only tracking on the quick flow group. In this mode only quick flow groups are supported, user will have only PGID stats and the packets will not contain any instrumentation block.
			EnableInstantaneousStatsSupport (bool): If true, enables instantaneous stats support
			EnableLagFlowBalancing (bool): 
			EnableMinFrameSize (bool): If true, IxNetwork will allow the stream to use smaller packet sizes. (In the case of IPv4 and Ethernet, 64 bytes will be allowed.) This is achieved by reducing the size of the instrumentation tag, which will be identified by receiving ports.
			EnableMulticastScalingFactor (bool): If true, traffic items with the Merged Destination Ranges option selected have be to manually regenerated by the user.
			EnableSequenceChecking (bool): If true, this field enables sequence checking. The default is false.
			EnableStaggeredStartDelay (bool): If checked, enables the staggered start delay function.
			EnableStaggeredTransmit (bool): If true, the start of transmit is staggered across ports. A 25-30 ms delay is introduced between the time one port begins transmitting and the time next port begins transmitting.
			EnableStreamOrdering (bool): If true, IxNetwork will allow stream ordering per RFC 2889.
			FrameOrderingMode (str(flowGroupSetup|none|peakLoading|RFC2889)): If true, enables frame ordering.
			GlobalStreamControl (str(continuous|iterations)): The Global Stream Control parameters.
			GlobalStreamControlIterations (number): If true, the user can specify how many times each packet stream will be transmitted.
			LargeErrorThreshhold (number): The user-configurable threshold value used to determine error levels for out-of-sequence, received packets.
			LearningFrameSize (number): Learns frame size
			LearningFramesCount (number): Learns frames count
			LearningFramesRate (number): Learns frames rate
			MacChangeOnFly (bool): If true, enables IxNetwork's gratuitous ARP capability. When enabled, IxNetwork listens for gratuitous ARP messages from its neighbors.
			MaxTrafficGenerationQueries (number): The maximum number of traffic generation queries. The default is 500.
			MplsLabelLearningTimeout (number): The MPLS label learning timeout in seconds. The default is 30 seconds.
			PeakLoadingReplicationCount (number): The peak loading replication count
			PreventDataPlaneToCpu (bool): Prevent all data plane packets from being forwarded to Port CPU (disabling this option requires Port CPU reboot)
			RefreshLearnedInfoBeforeApply (bool): This field refreshes the learned information from the DUT.
			UseRfc5952 (bool): Use RFC 5952 for formatting IPv6 addresses (:ffff:1.2.3.4)
			UseScheduledStartTransmit (bool): Use Scheduled Start Transmit
			UseTxRxSync (bool): If true, enables the transmit/receive port synchronization algorithm.
			WaitTime (number): The time (in seconds) to wait after Stop Transmit before stopping Latency Measurement.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def Apply(self):
		"""Executes the apply operation on the server.

		Apply the traffic configuration.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('apply', payload=payload, response_object=None)

	def ApplyApplicationTraffic(self):
		"""Executes the applyApplicationTraffic operation on the server.

		Apply the stateful traffic configuration.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyApplicationTraffic', payload=payload, response_object=None)

	def ApplyOnTheFlyTrafficChanges(self):
		"""Executes the applyOnTheFlyTrafficChanges operation on the server.

		Apply on the fly traffic changes.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyOnTheFlyTrafficChanges', payload=payload, response_object=None)

	def ApplyStatefulTraffic(self):
		"""Executes the applyStatefulTraffic operation on the server.

		Apply the traffic configuration for stateful traffic items only.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyStatefulTraffic', payload=payload, response_object=None)

	def GenerateIfRequired(self):
		"""Executes the generateIfRequired operation on the server.

		causes regeneration of dirty traffic items

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('generateIfRequired', payload=payload, response_object=None)

	def GetFrameCountForDuration(self, *args, **kwargs):
		"""Executes the getFrameCountForDuration operation on the server.

		Get the frame count for a specific duration.

		getFrameCountForDuration(Arg2:list)list
			Args:
				args[0] is Arg2 (list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=highLevelStream],arg2:number))): An array of structures. Each structure is one valid highLevelStream object reference and the duration to get the frame count for.

			Returns:
				list(number): An array of frame counts.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getFrameCountForDuration', payload=payload, response_object=None)

	def MakeStatelessTrafficUnapplied(self):
		"""Executes the makeStatelessTrafficUnapplied operation on the server.

		Move stateless traffic to unapplied state.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('makeStatelessTrafficUnapplied', payload=payload, response_object=None)

	def SendL2L3Learning(self):
		"""Executes the sendL2L3Learning operation on the server.

		Send L2 and L3 learning frames.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('sendL2L3Learning', payload=payload, response_object=None)

	def Start(self):
		"""Executes the start operation on the server.

		Start the traffic configuration.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('start', payload=payload, response_object=None)

	def StartApplicationTraffic(self):
		"""Executes the startApplicationTraffic operation on the server.

		Start the stateful traffic configuration.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('startApplicationTraffic', payload=payload, response_object=None)

	def StartStatefulTraffic(self):
		"""Executes the startStatefulTraffic operation on the server.

		Start stateful traffic items only.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('startStatefulTraffic', payload=payload, response_object=None)

	def StartStatelessTraffic(self):
		"""Executes the startStatelessTraffic operation on the server.

		Start the traffic configuration for stateless traffic items only.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		return self._execute('startStatelessTraffic', payload=payload, response_object=None)

	def StartStatelessTrafficBlocking(self):
		"""Executes the startStatelessTrafficBlocking operation on the server.

		Start the traffic configuration for stateless traffic items only. This will block until traffic is fully started.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		return self._execute('startStatelessTrafficBlocking', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		Stop the traffic configuration.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stop', payload=payload, response_object=None)

	def StopApplicationTraffic(self):
		"""Executes the stopApplicationTraffic operation on the server.

		Stop the stateful traffic configuration.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stopApplicationTraffic', payload=payload, response_object=None)

	def StopStatefulTraffic(self):
		"""Executes the stopStatefulTraffic operation on the server.

		Stop stateful traffic items only.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stopStatefulTraffic', payload=payload, response_object=None)

	def StopStatelessTraffic(self):
		"""Executes the stopStatelessTraffic operation on the server.

		Stop the stateless traffic items.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		return self._execute('stopStatelessTraffic', payload=payload, response_object=None)

	def StopStatelessTrafficBlocking(self):
		"""Executes the stopStatelessTrafficBlocking operation on the server.

		Stop the traffic configuration for stateless traffic items only. This will block until traffic is fully stopped.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		return self._execute('stopStatelessTrafficBlocking', payload=payload, response_object=None)
